# MDMPyClient

Python client for [MetadataManager](https://github.com/SDMXISTATTOOLKIT/META-DATA.MANAGER). It allows you to create codelist, concept schemes and more artefacts from simple code in python.

# Installation

You can install this package with pip.

    pip install mdmpyclient

# Documentation

[Documentation](https://mdmpyclient.readthedocs.io/en/latest/)